@@ -41,7 +41,6 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/color"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/docker"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/event"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner/runcontext"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
@@ -65,46 +64,40 @@ var (
 type HelmDeployer struct {
 	*latest.HelmDeploy
 
-	kubeContext       string
-	kubeConfig        string
-	namespace         string
-	forceDeploy       bool
-	addSkaffoldLabels bool
+	kubeContext string
+	kubeConfig  string
+	namespace   string
 
 	// packaging temporary directory, used for predictable test output
 	pkgTmpDir string
 
+	labels map[string]string
+
+	forceDeploy bool
+
 	// bV is the helm binary version
 	bV semver.Version
 }
 
 // NewHelmDeployer returns a configured HelmDeployer
-func NewHelmDeployer(runCtx *runcontext.RunContext) *HelmDeployer {
+func NewHelmDeployer(runCtx *runcontext.RunContext, labels map[string]string) *HelmDeployer {
 	return &HelmDeployer{
-		HelmDeploy:        runCtx.Cfg.Deploy.HelmDeploy,
-		kubeContext:       runCtx.KubeContext,
-		kubeConfig:        runCtx.Opts.KubeConfig,
-		namespace:         runCtx.Opts.Namespace,
-		forceDeploy:       runCtx.Opts.Force,
-		addSkaffoldLabels: runCtx.Opts.AddSkaffoldLabels,
-	}
-}
-
-// Labels returns the Kubernetes labels used by this deployer
-func (h *HelmDeployer) Labels() map[string]string {
-	return map[string]string{
-		constants.Labels.Deployer: "helm",
+		HelmDeploy:  runCtx.Pipeline().Deploy.HelmDeploy,
+		kubeContext: runCtx.GetKubeContext(),
+		kubeConfig:  runCtx.GetKubeConfig(),
+		namespace:   runCtx.GetKubeNamespace(),
+		forceDeploy: runCtx.ForceDeploy(),
+		labels:      labels,
 	}
 }
 
 // Deploy deploys the build results to the Kubernetes cluster
-func (h *HelmDeployer) Deploy(ctx context.Context, out io.Writer, builds []build.Artifact, labellers []Labeller) *Result {
-	event.DeployInProgress()
-
+func (h *HelmDeployer) Deploy(ctx context.Context, out io.Writer, builds []build.Artifact) ([]string, error) {
 	hv, err := h.binVer(ctx)
 	if err != nil {
-		return NewDeployErrorResult(fmt.Errorf(versionErrorString, err))
+		return nil, fmt.Errorf(versionErrorString, err)
 	}
+
 	logrus.Infof("Deploying with helm v%s ...", hv)
 
 	var dRes []Artifact
@@ -116,9 +109,7 @@ func (h *HelmDeployer) Deploy(ctx context.Context, out io.Writer, builds []build
 		results, err := h.deployRelease(ctx, out, r, builds, valuesSet, hv)
 		if err != nil {
 			releaseName, _ := util.ExpandEnvTemplate(r.Name, nil)
-
-			event.DeployFailed(err)
-			return NewDeployErrorResult(fmt.Errorf("deploying %q: %w", releaseName, err))
+			return nil, fmt.Errorf("deploying %q: %w", releaseName, err)
 		}
 
 		// collect namespaces
@@ -141,10 +132,9 @@ func (h *HelmDeployer) Deploy(ctx context.Context, out io.Writer, builds []build
 		}
 	}
 
-	event.DeployComplete()
-
-	labels := merge(h.addSkaffoldLabels, h, labellers...)
-	labelDeployResults(labels, dRes)
+	if err := labelDeployResults(h.labels, dRes); err != nil {
+		return nil, fmt.Errorf("adding labels: %w", err)
+	}
 
 	// Collect namespaces in a string
 	namespaces := make([]string, 0, len(nsMap))
@@ -152,7 +142,7 @@ func (h *HelmDeployer) Deploy(ctx context.Context, out io.Writer, builds []build
 		namespaces = append(namespaces, ns)
 	}
 
-	return NewDeploySuccessResult(namespaces)
+	return namespaces, nil
 }
 
 // Dependencies returns a list of files that the deployer depends on.
@@ -249,7 +239,7 @@ func (h *HelmDeployer) Cleanup(ctx context.Context, out io.Writer) error {
 }
 
 // Render generates the Kubernetes manifests and writes them out
-func (h *HelmDeployer) Render(ctx context.Context, out io.Writer, builds []build.Artifact, labellers []Labeller, offline bool, filepath string) error {
+func (h *HelmDeployer) Render(ctx context.Context, out io.Writer, builds []build.Artifact, offline bool, filepath string) error {
 	hv, err := h.binVer(ctx)
 	if err != nil {
 		return fmt.Errorf(versionErrorString, err)
@@ -434,6 +424,8 @@ func (h *HelmDeployer) getRelease(ctx context.Context, helmVersion semver.Versio
 			return nil
 		}, opts)
 
+	logrus.Debug(b.String())
+
 	return b, err
 }
 
@@ -752,3 +744,7 @@ func pairParamsToArtifacts(builds []build.Artifact, params map[string]string) (m
 
 	return paramToBuildResult, nil
 }
+
+func IsHelmChart(path string) bool {
+	return filepath.Base(path) == "Chart.yaml"
+}
