@@ -21,59 +21,39 @@ import (
 	"strings"
 
 	"github.com/google/uuid"
-
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/version"
 )
 
 const (
 	K8sManagedByLabelKey = "app.kubernetes.io/managed-by"
 	RunIDLabel           = "skaffold.dev/run-id"
-	unknownVersion       = "unknown"
-	empty                = ""
 )
 
 var runID = uuid.New().String()
 
 // DefaultLabeller adds K8s style managed-by label and a run-specific UUID label
 type DefaultLabeller struct {
-	opts    config.SkaffoldOptions
-	version string
-	runID   string
+	addSkaffoldLabels bool
+	customLabels      []string
+	runID             string
 }
 
-func NewLabeller(opts config.SkaffoldOptions) *DefaultLabeller {
-	verStr := version.Get().Version
-	if verStr == empty {
-		verStr = unknownVersion
-	}
+func NewLabeller(addSkaffoldLabels bool, customLabels []string) *DefaultLabeller {
 	return &DefaultLabeller{
-		opts:    opts,
-		version: verStr,
-		runID:   runID,
+		addSkaffoldLabels: addSkaffoldLabels,
+		customLabels:      customLabels,
+		runID:             runID,
 	}
 }
 
 func (d *DefaultLabeller) Labels() map[string]string {
-	labels := map[string]string{
-		K8sManagedByLabelKey: fmt.Sprintf("skaffold-%s", d.version),
-		RunIDLabel:           d.runID,
+	labels := map[string]string{}
+
+	if d.addSkaffoldLabels {
+		labels[K8sManagedByLabelKey] = "skaffold"
+		labels[RunIDLabel] = d.runID
 	}
 
-	if d.opts.Cleanup {
-		labels["skaffold.dev/cleanup"] = "true"
-	}
-	if d.opts.Tail {
-		labels["skaffold.dev/tail"] = "true"
-	}
-	if d.opts.Namespace != "" {
-		labels["skaffold.dev/namespace"] = d.opts.Namespace
-	}
-	for i, profile := range d.opts.Profiles {
-		key := fmt.Sprintf("skaffold.dev/profile.%d", i)
-		labels[key] = profile
-	}
-	for _, cl := range d.opts.CustomLabels {
+	for _, cl := range d.customLabels {
 		l := strings.SplitN(cl, "=", 2)
 		if len(l) == 1 {
 			labels[l[0]] = ""
@@ -81,6 +61,7 @@ func (d *DefaultLabeller) Labels() map[string]string {
 		}
 		labels[l[0]] = l[1]
 	}
+
 	return labels
 }
 
