@@ -18,6 +18,7 @@ package initializer
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"io"
 	"io/ioutil"
@@ -44,6 +45,14 @@ func DoInit(ctx context.Context, out io.Writer, c config.Config) error {
 		return err
 	}
 
+	// helm projects can't currently be bootstrapped automatically by skaffold, so we fail fast and link to our docs instead.
+	if len(a.ChartPaths()) > 0 {
+		//nolint
+		return errors.New(`Projects set up to deploy with helm must be manually configured.
+
+See https://skaffold.dev/docs/pipeline-stages/deployers/helm/ for a detailed guide on setting your project up with skaffold.`)
+	}
+
 	deployInitializer := deploy.NewInitializer(a.Manifests(), a.KustomizeBases(), a.KustomizePaths(), c)
 	images := deployInitializer.GetImages()
 
